<?php 
class WCPST_Product
{
	public function __construct()
	{
		if(is_admin())
		{
			add_action('wp_ajax_wcpst_get_products_list', array(&$this, 'ajax_get_products_partial_list'));
			add_action('wp_ajax_wcpst_get_product_categories_list', array(&$this, 'ajax_get_product_categories_partial_list'));
		}
	}
	public function save_product_meta($product_id, $meta_name = '_wcpst_shared_purchase_price', $meta_value = "")
	{
		update_post_meta( $product_id, $meta_name, esc_attr( $meta_value ) );
	}
	public function get_product_meta($product_id, $meta_name = '_wcpst_shared_purchase_price', $default_value = null)
	{
		$result = get_post_meta( $product_id, $meta_name, true );
		return !empty( $result ) ? $result : $default_value;
	}
	public function get_product_meta_sql($product_id, $meta_name = '_wcpst_shared_purchase_price', $default_value = 0)
	{
		global $wpdb;
		$query = "SELECT product_purchase_cost.meta_value 
				  FROM {$wpdb->postmeta} AS product_purchase_cost
				  WHERE product_purchase_cost.post_id = {$product_id} 
				  AND product_purchase_cost.meta_key = '{$meta_name}' ";
				
		$result = $wpdb->get_results($query);
		/* if(!empty($result))
			wcst_var_dump($result); */
		return !empty($result) ? $result[0]->meta_value : $default_value;
	}
	public function ajax_get_products_partial_list()
	 {
		 $products = $this->get_product_list($_GET['product']);
		 echo json_encode( $products);
		 wp_die();
	 }
	  public function ajax_get_product_categories_partial_list()
	 {
		 $product_categories = $this->get_product_category_list($_GET['product_category']);
		 echo json_encode( $product_categories);
		 wp_die();
	 }
	 
	 public function get_product_list($search_string = null)
	 {
		global $wpdb, $wcpst_wpml_helper;
		$query_string = "SELECT products.ID as id, products.post_title as product_name, product_meta.meta_value as product_sku
							 FROM {$wpdb->posts} AS products
							 LEFT JOIN {$wpdb->postmeta} AS product_meta ON product_meta.post_id = products.ID AND product_meta.meta_key = '_sku'
							 WHERE products.post_type = 'product'
							";
		if($search_string)
				$query_string .=  " AND ( products.post_title LIKE '%{$search_string}%' OR product_meta.meta_value LIKE '%{$search_string}%' OR products.ID LIKE '%{$search_string}%' ) 
								   AND products.post_type ='product' ";
		
		$query_string .=  " GROUP BY products.ID ";
		$result = $wpdb->get_results($query_string ) ;
		
		//WPML
		if($wcpst_wpml_helper->wpml_is_active())
		{
			$result = $wcpst_wpml_helper->remove_translated_id($result);
		}
		
		return $result;
	 }
	 
	 public function get_product_category_list($search_string = null)
	 {
		 global $wpdb, $wcpst_wpml_helper;
		  $query_string = "SELECT product_categories.term_id as id, product_categories.name as category_name
							 FROM {$wpdb->terms} AS product_categories
							 LEFT JOIN {$wpdb->term_taxonomy} AS tax ON tax.term_id = product_categories.term_id 							 						 	 
							 WHERE tax.taxonomy = 'product_cat' 
							 AND product_categories.slug <> 'uncategorized' 
							";
		 if($search_string)
					$query_string .=  " AND ( product_categories.name LIKE '%{$search_string}%' )";
			
		$query_string .=  " GROUP BY product_categories.term_id ";
		$result = $wpdb->get_results($query_string ) ;
		
		//WPML
		if($wcpst_wpml_helper->wpml_is_active())
		{
			$result = $wcpst_wpml_helper->remove_translated_id($result, 'product_cat');
		} 
		
		return $result;
	 }
	 public static function get_variation_complete_name($variation_id, $full_name = false)
		{
			$error = false;
			$variation = null;
			try
			{
				$variation = new WC_Product_Variation($variation_id);
			}catch(Exception $e){$error = true;}
			if($error) 
				try
				{
					$error = false;
					$variation = new WC_Product($variation_id);
					return $variation->get_title();
				}catch(Exception $e){$error = true;}
			if($error)
				return "";
		
			$product_name = $full_name ? $variation->get_title()." - " : "";	
			if($product_name == " - ")
				return false;
			$attributes_counter = 0;
			foreach($variation->get_variation_attributes( ) as $attribute_name => $value)
			{
				if($value == "" || $value == " ")
					continue;
				
				if($attributes_counter > 0)
					$product_name .= ", ";
				$meta_key = urldecode( str_replace( 'attribute_', '', $attribute_name ) ); 
				
				$product_name .= " ".wc_attribute_label($meta_key).": ".$value;
				$attributes_counter++;
			}
			return $product_name;
		}
	 public static function is_variable($product_id)
	 {
		
		 $product = wc_get_product( $product_id );
		// wcpst_var_dump($product);
		 if($product->get_type() == 'variable')
			return true;
		
		 return false;
	 }
	 public static function get_variations($product_id)
	 {
		global $wpdb;
		 $query = "SELECT products.ID
		           FROM {$wpdb->posts} AS products 
				   WHERE products.post_parent = {$product_id} ";
		 $result =  $wpdb->get_results($query); 
		 //wcpst_var_dump($result);
		 return isset($result) ? $result : null;		 
	 }
}
?>